===============================
estat
===============================

Download data from Japanese Government Statistics and save it as CSV format files.

How to use
--------
First you must get AppID from e-Stat site from here (https://www.e-stat.go.jp/).
Next do the followings.
```
import estat
estat.download()
```
You can find csv format files in $HOME/estat/data-cache.

Author
--------
kenbunji
https://github.com/bunjiken/estat

License
--------
Licensed under the MIT license.

Remarks
--------
This program is created referring to this site
https://github.com/e-stat-api/adaptor
